@@ -37,3 +37,23 @@ class Session:
         Args:
             connection (Connection): connection of the session
         """
+
+    async def set(self, **kwargs):
+        """
+        Set session variables.
+
+        Args:
+            **kwargs: mapping of variable names to values
+        """
+
+    async def show_columns(self, database, table):  # pylint: disable=unused-argument
+        """
+        Show column metadata.
+
+        Args:
+            database (str): database name
+            table (str): table name
+        Returns:
+            list[mysql_mimic.results.Column|dict]: columns
+        """
+        return []
